summaryrefslogtreecommitdiffstats
path: root/src/privsep-root.c
diff options
context:
space:
mode:
Diffstat (limited to 'src/privsep-root.c')
-rw-r--r--src/privsep-root.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/privsep-root.c b/src/privsep-root.c
index b09a67da..92406c4d 100644
--- a/src/privsep-root.c
+++ b/src/privsep-root.c
@@ -648,7 +648,7 @@ ps_root_startcb(void *arg)
{
struct dhcpcd_ctx *ctx = arg;
- if (ctx->options & DHCPCD_MASTER)
+ if (ctx->options & DHCPCD_MANAGER)
setproctitle("[privileged actioneer]");
else
setproctitle("[privileged actioneer] %s%s%s",
@@ -660,7 +660,7 @@ ps_root_startcb(void *arg)
/* Open network sockets for sending.
* This is a small bit wasteful for non sandboxed OS's
* but makes life very easy for unicasting DHCPv6 in non master
* mode as we no longer care about address selection.
* We can't call shutdown SHUT_RD on the socket because it's
* not connectd. All we can do is try and set a zero sized
@@ -707,8 +707,8 @@ ps_root_startcb(void *arg)
#ifdef PLUGIN_DEV
/* Start any dev listening plugin which may want to
* change the interface name provided by the kernel */
- if ((ctx->options & (DHCPCD_MASTER | DHCPCD_DEV)) ==
- (DHCPCD_MASTER | DHCPCD_DEV))
+ if ((ctx->options & (DHCPCD_MANAGER | DHCPCD_DEV)) ==
+ (DHCPCD_MANAGER | DHCPCD_DEV))
dev_start(ctx, ps_root_handleinterface);
#endif
@@ -660,7 +660,7 @@ ps_root_startcb(void *arg)
/* Open network sockets for sending.
* This is a small bit wasteful for non sandboxed OS's
- * but makes life very easy for unicasting DHCPv6 in non master
+ * but makes life very easy for unicasting DHCPv6 in non manager
* mode as we no longer care about address selection.
* We can't call shutdown SHUT_RD on the socket because it's